{
    "recommendations": [
        // Code Runner
        "formulahendry.code-runner",
        // Material Icon Theme
        "pkief.material-icon-theme",
        "vscode-icons-team.vscode-icons",
        // IntelliJ IDEA Keybindings
        "k--kato.intellij-idea-keybindings",
        // Prettier - Code formatter
        "esbenp.prettier-vscode",
        // gitignore
        "codezombiech.gitignore",
        "mhutchie.git-graph",
        "oderwat.indent-rainbow",
        //----------------------------------------
        "billchiu.vscode-coder4",
        //----------------------------------------
        "kevinrose.vsc-python-indent",
        "donjayamanne.python-environment-manager",
        "ms-python.python",
        "ms-python.black-formatter",
        "ms-python.flake8",
        "ms-python.vscode-pylance",
        "ms-python.debugpy",
        "ms-python.isort",
        "ms-python.autopep8",
        "ms-python.pylint"
    ]
}