{
    "recommendations": [
        // Code Runner
        "formulahendry.code-runner",
        // Material Icon Theme
        "pkief.material-icon-theme",
        "vscode-icons-team.vscode-icons",
        // IntelliJ IDEA Keybindings
        "k--kato.intellij-idea-keybindings",
        // Prettier - Code formatter
        "esbenp.prettier-vscode",
        // gitignore
        "codezombiech.gitignore",
        // Paste JSON as Code
        "quicktype.quicktype",
        // Git Graph
        "mhutchie.git-graph",
        //----------------------------------------
        // XML
        "redhat.vscode-xml",
        // YAML
        "redhat.vscode-yaml",
        // json
        "zainchen.json",
        // Even Better TOML
        "tamasfe.even-better-toml",
        //----------------------------------------
        // Markdown All in One
        "yzhang.markdown-all-in-one",
        // Prettify JSON
        "mohsen1.prettify-json",
        // Better Comments
        "aaron-bond.better-comments",
        //----------------------------------------
        // Path Intellisense
        "christian-kohler.path-intellisense",
        //----------------------------------------
        "dbaeumer.vscode-eslint",
        "xabikos.javascriptsnippets",
        "christian-kohler.npm-intellisense"
    ]
}