{
  "name": "{{project_name}}",
  "version": "{{project_version}}",
  "main": "src/index.ts",
  "license": "MIT",
  "bin": {
    "demo": "dist/index.js"
  },
  "scripts": {
    "build": "tsc",
    "start": "tsx src/index.ts"
  },
  "devDependencies": {
  },
  "dependencies": {
  }
}