[project]
name = "{{project_name}}"
description = "{{project_description}}"
readme = "README.md"
requires-python = ">=3.11"
license = { text = "MIT License" }
authors = [{ name = "{{authors_name}}", email = "{{authors_email}}" }]
maintainers = [{ name = "{{authors_name}}", email = "{{authors_email}}" }]
dynamic = ["version", "dependencies"]
classifiers = [
    "License :: OSI Approved :: MIT License",
    "Environment :: Console :: Curses",
    "Operating System :: OS Independent",
    "Programming Language :: Python :: 3",
    "Topic :: Utilities",
]

[project.optional-dependencies]
dev = ["build", "twine"]

[project.scripts]
{{project_name}} = "{{project_name}}.cmdline:run"

[build-system]
requires = ["setuptools"]
build-backend = "setuptools.build_meta"

[tool.setuptools.dynamic]
version = { attr = "{{project_name}}.__VERSION__" }
dependencies = { file = ["requirements.txt"] }

[tool.setuptools.packages.find]
include = ["{{project_name}}*"]

[tool.setuptools]
include-package-data = true

[tool.setuptools.package-data]
"{{project_name}}" = ["templates/*", "static/**/*"]

[tool.black]
line-length = 120
