{
  "workbench.iconTheme": "vscode-icons",
  "workbench.colorTheme": "Default Dark+",
  "editor.fontSize": 15,
  "editor.formatOnSave": true,
  "window.zoomLevel": 0.8,
  "files.autoSave": "afterDelay",
  "editor.lineHeight": 1.6,
  
  "prettier.tabWidth": 2,
  "python.envFile": "${workspaceFolder}/.venv",
  "python.languageServer": "Pylance",
  "flake8.args": [
    "--max-line-length=120"
  ],
  "black-formatter.args": [
    "--line-length=120"
  ],
  "python.analysis.autoFormatStrings": true,
  "python.analysis.autoImportCompletions": true,
  "python.analysis.completeFunctionParens": true,
  "python.analysis.supportDocstringTemplate": true,
  "search.exclude": {
    "**/.venv": true,
    "**/build": true,
    "**/.vscode": true,
    "**/.idea": true
  },
  "files.exclude": {
    "**/__pycache__": true,
    "**/.idea": true,
    "**/*.egg-info": true
  },
}