{
    "workbench.iconTheme": "vscode-icons",
    "workbench.colorTheme": "Default Dark+",
    "window.zoomLevel": 0.8,
    "editor.fontSize": 15,
    "editor.lineHeight": 1.6,
    "[javascript]": {
        "editor.defaultFormatter": "vscode.typescript-language-features"
    },
    "[typescript]": {
        "editor.defaultFormatter": "vscode.typescript-language-features"
    },
    "[json]": {
        "editor.defaultFormatter": "vscode.json-language-features"
    },
    "search.exclude": {
        "**/node_modules": true,
        "**/dist": true,
        "**/bin": true,
        "**/.vscode": true,
    }
}